%define ALD_Ver		2.0

Name:         atk

License:      LGPLv2+
Summary:      Accessibility Toolkit
Group:        System Environment/Libraries
Version:      2.36.0
Release:      0

#https://download.gnome.org/sources/atk/

Requires:	glib2 >= 2.38.0

Source: %{name}-%{version}.tar.xz

%define DestDir		/Gtk3/3.0
# -----------------------------------------------------

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=armv7hl -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

#------------------ CROSS DIR --------------------

%define docdir		%{_defaultdocdir}/%{name}

%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{have_auto_local}
%define __os_install_post %{nil}
%define CrossPath	%(%{auto_local} -GetCrossPath -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu})
%endif

# ------------------- description ------------------------------------
%description
Handy library of accessibility functions. Development libs and headers
are in atk-devel.
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
%description devel
These libraries are needed to compile C code.
#-------------------------------
%package locale
Summary:      locale
%description locale
Locale
#-------------------------------
%package doc
Summary:      doc for %{name}
%description doc
doc for %{name}
#-------------------------------
%package %{_target_cpu}
Summary:      %{name} Cross-%{_target_cpu}
Buildarch:    noarch
autoreqprov:  0
%description %{_target_cpu}
%{name} Cross-%{_target_cpu}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
export  PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -O2 -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables"

CFLAGS="$OPTFLAGS -std=gnu99"
LDFLAGS="-Wl,--gc-sections"
CXXFLAGS="$OPTFLAGS"

%define srcdir "`pwd`"

meson   --buildtype=plain \
        --prefix=%{_prefix} \
        --libdir=%{_libdir} \
        --libexecdir=%{_libexecdir} \
        --bindir=%{_bindir} \
        --sbindir=%{_sbindir} \
        --includedir=%{_includedir} \
        --datadir=%{_datadir} \
        --mandir=%{_mandir} \
        --infodir=%{_infodir} \
        --localedir=%{_datadir}/locale \
        --sysconfdir=%{_sysconfdir} \
        --localstatedir=%{_localstatedir} \
        --sharedstatedir=%{_sharedstatedir} \
	--wrap-mode=nodownload \
	-Dintrospection=false \
	-Ddocs=true \
	%{srcdir}  _Build \
	&>FConfigure_log.txt

ninja -C _Build &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
export  PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

DESTDIR=$RPM_BUILD_ROOT ninja -C _Build install \
	 &>Finstall_log.txt

cp AUTHORS README $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/lgpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} -DelLocCrossDir=%{_bindir}
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
%defattr(-, root, root)
%{_libdir}/*.so.*
%{docdir}

%files locale
%{_datadir}/locale

%files devel
%defattr(-, root, root)
%{_includedir}
%{_libdir}/*.so
%{_libdir}/pkgconfig

%files doc
%{_datadir}/gtk-doc/html/atk

# ------------------- Cross Files ------------------------------------
%if %{MakeLocCross} && %{have_auto_local}

%files %{_target_cpu}
%{CrossPath}%{_libdir}
%{CrossPath}%{_includedir}
%{CrossPath}%{docdir}

%endif # MakeLocCross
